#
# spec file for package flowblade
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           flowblade
Version:        1.16
Release:        1.3
Summary:        Multitrack non-linear video editor
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://jliljebl.github.io/flowblade
Source:         https://github.com/jliljebl/flowblade/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  frei0r-plugins >= 1.4
BuildRequires:  gobject-introspection
BuildRequires:  python-devel >= 2.7.0
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
Requires:       dbus-1-python
Requires:       ffmpeg
Requires:       frei0r-plugins >= 1.4
Requires:       ladspa
Requires:       ladspa-swh-plugins
Requires:       libmlt6-data
Requires:       libmlt6-modules
Requires:       python-cairo
Requires:       python-gobject
Requires:       python-gobject-Gdk
Requires:       python-imaging
Requires:       python-mlt
Requires:       python-numpy
Requires:       rsvg-view
Requires:       sox
Recommends:     gmic
BuildArch:      noarch
# SECTION Check dependencies:
BuildRequires:  dbus-1-python
BuildRequires:  libmlt6-modules >= 6.6.0
BuildRequires:  python-cairo
BuildRequires:  python-imaging
BuildRequires:  python-mlt
BuildRequires:  python-numpy
BuildRequires:  rsvg-view
# / SECTION

%description
Flowblade is designed to provide a fast, precise and robust editing experience.

In Flowblade clips are usually automatically placed tightly after or between
clips when they are inserted on the timeline. Edits are fine tuned by trimming
in and out points of clips, or by cutting and deleting parts of clips.

Flowblade provides powerful tools to mix and filter video and audio.

%lang_package

%prep
%setup -q -n %{name}-%{version}/%{name}-trunk

# Check MLT build with SDL 1.2
rpm -qR libmlt6-modules | grep -w libSDL || 'SDL 1.2 not found' 2> /dev/null
#
sed -i 's|%{_datadir}/pyshared|%{python_sitelib}|' %{name}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

mkdir -p %{buildroot}%{_datadir}/locale
mv %{buildroot}{%{python_sitelib}/Flowblade/locale/*,%{_datadir}/locale/}
find %{buildroot} -type f -name "*.po*" -delete -print

rm -rf %{buildroot}%{_libexecdir}/mime/packages/%{name}

%fdupes %{buildroot}%{python_sitelib}
%find_lang %{name}

# Fix: non-executable-script
pushd %{buildroot}
for _file in $(grep -rl '^\#\!\/'); do
    ! echo $_file | grep '\/usr\/bin\|\/launch' || chmod 0755 $_file 
    find -name ${_file##*/} -type f -perm 644 -exec sed '/^\#\!/d' -i {} \+
    find -name ${_file##*/} -type f -perm 755 -exec sed '/^\#\!\/.\+py/c\#\!%{_bindir}/python' -i {} \+
    find -name ${_file##*/} -type f -perm 755 -exec sed '/^\#\!\/.\+sh/c\#\!/bin/bash' -i {} \+
done
%py_compile .%{python_sitelib}
popd

%post
%mime_database_post
%desktop_database_post

%postun
%mime_database_postun
%desktop_database_postun

%files
%license COPYING
%doc AUTHORS README docs/RELEASE_NOTES*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.??g
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/%{name}.?%{ext_info}
%{python_sitelib}/Flowblade/
%{python_sitelib}/%{name}*info

%files lang -f %{name}.lang

%changelog
* Sun Apr  1 2018 avvissu@yandex.by
- Update to 1.16:
  * see /usr/share/doc/packages/flowblade/RELEASE_NOTES
- Change the home page
- Refresh dependencies
- Fix: non-executable-script
- Spec file cleanup
* Wed Oct  4 2017 avvissu@yandex.by
- Update to 1.14:
  * see /usr/share/doc/packages/flowblade/RELEASE_NOTES
- Use python-gobject-Gdk instead of python-gobject
* Tue Mar 21 2017 avvissu@yandex.by
- Update to 1.12.2:
  * see /usr/share/doc/packages/flowblade/RELEASE_NOTES
* Thu Jan 12 2017 avvissu@yandex.by
- Update to 1.10:
  * see /usr/share/docpackages/flowblade/RELEASE_NOTES
- Check list of dependencies
* Sat Oct 22 2016 avvissu@yandex.by
- Update to 1.8:
  * see /usr/share/docpackages/flowblade/RELEASE_NOTES
* Tue Jan 26 2016 avvissu@yandex.ru
- Update to 1.4:
  * see /usr/share/docpackages/flowblade/RELEASE_NOTES
- Dropped dependencies: python-gnome python-gtk
- Add dependencies: python-gobject
- Remove MIME-type from /usr/lib/mime/packages/
* Wed Mar  4 2015 avvissu@yandex.ru
- Initial release
